@@ -9,5 +9,5 @@ from pytoughreact.chemical.perm_poro_zone import PermPoro
 from pytoughreact.writers.bio_writing import t2bio
 from pytoughreact.chemical.biomass_composition import Component, Gas, Water_Bio, Biomass
 from pytoughreact.chemical.bio_process_description import Process, BIODG
-from pytoughreact.results.result_single import FileReadSingle
+from pytoughreact.plotting.plot_single import PlotSingle
 from .version import __version__
