@@ -51,8 +51,20 @@ class t2bio_parser(fixed_format_file):
                                            t2bio_format_specification, read_function)
 
     def read_multi_value_line(self, variable, linetype):
-        """Reads a line of parameter multi values from the file into a dictionary variable.
-        Null values are ignored."""
+        """ Reads a line of parameter multi values from the file into a dictionary variable.
+        Null values are ignored.
+
+        Parameters
+        -----------
+        variable :  str
+            variable to be read
+        linetype: str
+            type of line to be read
+
+        Returns
+        --------
+
+        """
         spec = self.specification[linetype]
         vals = self.read_values(linetype)
         if len(spec[0]) < 6:
@@ -63,6 +75,20 @@ class t2bio_parser(fixed_format_file):
             variable[linetype] = vals
 
     def read_params_value_line(self, variable, linetype):
+        """ Reads a line of parameter values from the file into a dictionary variable.
+        Null values are ignored.
+
+        Parameters
+        -----------
+        variable :  str
+            variable to be read
+        linetype: str
+            type of line to be read
+
+        Returns
+        --------
+
+        """
         spec = self.specification[linetype]
         vals = self.read_values(linetype)
         if len(spec[0]) > 2:
@@ -193,8 +219,18 @@ class t2bio(t2data):
              self.write_indom]))
 
     def get_present_sections(self):
-        """Returns a list of TOUGH2 section keywords for which there are
-        corresponding data in the t2bio object."""
+        """ Returns a list of TOUGH2 section keywords for which there are
+        corresponding data in the t2bio object.
+
+        Parameters
+        -----------
+
+        Returns
+        --------
+        present_sections : list
+            Sections with corresponding data in the t2bio object
+
+        """
         data_present = dict(zip(
             t2bio_sections,
             [self.simulator,
@@ -229,8 +265,19 @@ class t2bio(t2data):
     present_sections = property(get_present_sections)
 
     def section_insertion_index(self, section):
-        """Determines an appropriate position to insert the specified section
+        """ Determines an appropriate position to insert the specified section
         in the internal list of data file sections.
+
+        Parameters
+        -----------
+        section :  list
+            list of sections
+
+        Returns
+        --------
+        parameter : int
+            Appropriate position to insert the specified section in the internal list of data file sections.
+
         """
         try:
             listindex = t2bio_sections.index(section)
@@ -259,7 +306,28 @@ class t2bio(t2data):
 
     def run(self, save_filename='', incon_filename='', runlocation='', simulator='AUTOUGH2_2',
             silent=False, output_filename=''):
-        """ Runs simulation using TMVOC """
+        """ Runs simulation using TMVOC
+
+        Parameters
+        -----------
+        save_filename : str
+            filename of SAVE file
+        incon_filename : str
+            filename of INCON file
+        run_location : str
+            path to Executable and required files
+        simulator : str
+            simulator executable name
+        silent: boolean
+            if output messages should be written out
+        output_filename: str
+            name of output file
+
+        Returns
+        --------
+
+        """
+
         if runlocation:
             os.chdir(os.path.dirname(os.path.realpath(__file__)))
             print(os.path.dirname(os.path.realpath(__file__)))
@@ -305,7 +373,19 @@ class t2bio(t2data):
                 call(cmd, stdin=infile, stdout=outfile)
 
     def read_rocktypes(self, infile):
-        """Reads grid rock types"""
+        """ Reads grid rock types
+
+        Parameters
+        -----------
+        infile : str
+            Input file processor
+
+        Returns
+        --------
+        rocktype: self
+            adds rocktype information to grid
+
+        """
         self.grid.rocktypelist = []
         self.grid.rocktype = {}
         line = padstring(infile.readline())
@@ -330,7 +410,19 @@ class t2bio(t2data):
             line = padstring(infile.readline())
 
     def read_chem(self, infile):
-        """ Reads chemical components """
+        """ Reads chemical components
+
+        Parameters
+        -----------
+        infile : str
+            Input file processor
+
+        Returns
+        --------
+        components: self
+            adds components to grid
+
+        """
         params = infile.read_values('chemp')
         all_comp = []
         for i in range(int(params[0])):
@@ -362,7 +454,18 @@ class t2bio(t2data):
         self.components = all_comp
 
     def write_chem(self, outfile):
-        """ Writes chemical components """
+        """ Writes chemical components
+
+        Parameters
+        -----------
+        outfile : str
+            output file processor
+
+        Returns
+        --------
+
+        """
+
         outfile.write('CHEMP\n')
         vals = [len(self.components)]
         outfile.write_values(vals, 'chemp')
@@ -387,7 +490,19 @@ class t2bio(t2data):
         pass
 
     def read_gas(self, infile):
-        """ Reads Gases """
+        """ Reads Gases
+
+        Parameters
+        -----------
+        infile : str
+            Input file processor
+
+        Returns
+        --------
+        components: self
+            adds gases to grid
+
+        """
         params = infile.read_values('ncgas')
         all_comp = []
         for i in range(int(params[0])):
@@ -398,7 +513,17 @@ class t2bio(t2data):
         self.gas = all_comp
 
     def write_gas(self, outfile):
-        """ Writes Gases """
+        """ Writes Gases
+
+        Parameters
+        -----------
+        outfile : str
+            output file processor
+
+        Returns
+        --------
+
+        """
         outfile.write('NCGAS\n')
         vals = [len(self.gas)]
         outfile.write_values(vals, 'ncgas')
@@ -407,16 +532,40 @@ class t2bio(t2data):
             outfile.write(vals + '\n')
 
     def reset_bio_dicta(self, all_components):
-        """ Resets the BIO dicitonary """
-        dicta_all = []
+        """ Resets the BIO dicitonary
+
+        Parameters
+        -----------
+        all_components : list
+            all components present
+
+        Returns
+        --------
+        empty_list: list
+            empty list containing no parameters
+
+        """
+        empty_list = []
         for i in range(len(all_components)):
             dicta = {}
             dicta[all_components[i]] = []
-            dicta_all.append(dicta)
-        return dicta_all
+            empty_list.append(dicta)
+        return empty_list
 
     def read_biodg(self, infile):
-        """ Reads Biodegradation Block """
+        """ Reads Biodegradation Block
+
+        Parameters
+        -----------
+        infile : str
+            Input file processor
+
+        Returns
+        --------
+        components: self
+            adds biodegradation block to grid
+
+        """
         params = infile.read_values('biodg')
         number_of_processes = int(infile.read_values('biodg1')[0])
         process_details = []
@@ -474,7 +623,17 @@ class t2bio(t2data):
         self.biodg.append(biodegradation)
 
     def write_biodg(self, outfile):
-        """ Writes Biodegradation Block """
+        """ Writes Biodegradation Block
+
+        Parameters
+        -----------
+        outfile : str
+            output file processor
+
+        Returns
+        --------
+
+        """
         outfile.write('BIODG\n')
         value = self.biodg[0]
         vals = value.getFirstSet()
@@ -540,10 +699,33 @@ class t2bio(t2data):
             outfile.write_values(vals, 'biodg2.1')
 
     def read_solids(self, infile):
-        """ Reads Solids Block """
+        """ Reads Solids Block
+
+        Parameters
+        -----------
+        infile : str
+            Input file processor
+
+        Returns
+        --------
+        components: self
+            adds solid block to grid
+
+        """
         pass
 
     def write_solids(self, outfile):
+        """ Writes Solid Block
+
+        Parameters
+        -----------
+        outfile : str
+            output file processor
+
+        Returns
+        --------
+
+        """
         outfile.write('SOLIDS\n')
         outfile.write_values(len(self.solids), 'solids1')
         for i in range(len(self.solids)):
@@ -552,8 +734,20 @@ class t2bio(t2data):
             outfile.write_values(vals, 'solids2')
 
     def read_parameters(self, infile):
-        """ Reads Parameters Block """
-        """Reads simulation parameters"""
+        """ Reads Parameters Block
+
+        Parameters
+        -----------
+        infile : str
+            Input file processor
+
+        Returns
+        --------
+        components: self
+            adds parameters block to grid
+
+        """
+
         spec = ['param1', 'param1_autough2'][self.type == 'AUTOUGH2']
         # infile.read_value_line(self.parameter, spec)
         infile.read_params_value_line(self.parameter, spec)
@@ -588,7 +782,17 @@ class t2bio(t2data):
         return line
 
     def write_parameters(self, outfile):
-        """ Writes Parameters Block """
+        """ Writes Parameters Block
+
+        Parameters
+        -----------
+        outfile : str
+            output file processor
+
+        Returns
+        --------
+
+        """
         outfile.write('PARAM\n')
         from copy import copy
         paramw = copy(self.parameter)
@@ -614,13 +818,37 @@ class t2bio(t2data):
             outfile.write('\n')
 
     def read_more_options(self, infile):
-        """Reads additional parameter options"""
+        """ Reads additional parameter options
+
+        Parameters
+        -----------
+        infile : str
+            Input file processor
+
+        Returns
+        --------
+        components: self
+            adds more_options block to grid
+
+        """
         infile.read_value_line(self.__dict__, '_more_option_str')
         momops = self._more_option_str.rstrip().ljust(21).replace(' ', '0')
         self.more_option = np.array([0] + [int(mop) for mop in momops], int)
 
     def read_multi(self, infile):
-        """Reads EOS parameters"""
+        """ Reads EOS parameters
+
+        Parameters
+        -----------
+        infile : str
+            Input file processor
+
+        Returns
+        --------
+        components: self
+            adds multi block to grid
+
+        """
         spec = ['multi', 'multi_autough2'][self.type == 'AUTOUGH2']
         # spec = self.specification[spec]
         # vals = infile.read_values('multi')
@@ -631,14 +859,37 @@ class t2bio(t2data):
             self.multi['eos'] = self.multi['eos'].strip()
 
     def write_start(self, outfile):
-        """ Writes Start Block """
+        """ Writes Start Block
+
+        Parameters
+        -----------
+        outfile : str
+            output file processor
+
+        Returns
+        --------
+
+        """
         if self.start:
             outfile.write('START\n')
 
     def read(self, filename='', meshfilename='', runlocation=''):
-        """Reads data from file.  Mesh data can optionally be read from an
+        """ Reads data from file.  Mesh data can optionally be read from an
         auxiliary file.  Extra precision data will also be read from
         an associated '.pdat' file, if it exists.
+
+        Parameters
+        -----------
+        filename : str
+            file to read
+        meshfilename : str
+            Mesh file to read
+        runlocation : str
+            Path containing executables
+
+        Returns
+        --------
+
         """
         if runlocation:
             if not os.path.isdir(runlocation):
@@ -692,7 +943,7 @@ class t2bio(t2data):
 
     def write(self, filename='', meshfilename='', runlocation='',
               extra_precision=None, echo_extra_precision=None):
-        """Writes data to file.  Mesh data can optionally be written to an
+        """ Writes data to file.  Mesh data can optionally be written to an
         auxiliary file.  For AUTOUGH2, if extra_precision is True or a
         list of section names, the corresponding data sections will be
         written to an extra precision file; otherwise, the same
@@ -700,6 +951,23 @@ class t2bio(t2data):
         also be written out as extra precision.  If
         echo_extra_precision is True, the extra precision sections
         will also be written to the main data file.
+
+        Parameters
+        -----------
+        filename : str
+            file to read
+        meshfilename : str
+            Mesh file to read
+        runlocation : str
+            Path containing executables
+        extra_precision: boolean
+            Required for AUTOUGH from PYTOUGH
+        echo_extra_precision: boolean
+            Required for AUTOUGH from PYTOUGH
+
+        Returns
+        --------
+
         """
 
         if runlocation:
